Stan Math Library: stan/math/rev/scal/fun/Phi.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
Phi.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/scal/fun/Phi.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::Phi (const stan::math::var &a)
| The unit normal cumulative density function for variables (stan). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.